@@ -1,47 +1,36 @@
-assertFunbyApproach <- function(funbyApproach) {
-  funbyApproach <- match.arg(funbyApproach, c("base", "fasttime", "RcppCCTZ"))
+assertFunbyApproach <- function(.dateTime, .helpers) {
+  funbyApproach <- match.arg(
+    .helpers[["funbyApproach"]],
+    c("timechange", "base", "fasttime", "RcppCCTZ")
+  )
 
-  if (funbyApproach == "fasttime" &&
-      !requireNamespace("fasttime", quietly = TRUE)) {
-    stop(
-      'Package "fasttime" must be installed for this approach.',
-      call. = FALSE
-    )
+  if (funbyApproach == "fasttime") {
+    if (!requireNamespace("fasttime", quietly = TRUE)) {
+      stop('Package "fasttime" must be installed for this approach.')
+    }
+
+    if (year(.dateTime[1L]) < 1970L || year(last(.dateTime)) > 2199L) {
+      stop("Timestamps must be between the years 1970 and 2199 for this approach.")
+    }
+
+    if (!grepl(
+      "^(Etc/)?(UCT|UTC)$|^(Etc/)?GMT(\\+|-)?0?$",
+      .helpers[["timezone"]],
+      ignore.case = TRUE
+    )) {
+      stop('Time zone must be "UTC" or equivalent for this approach.')
+    }
   } else if (funbyApproach == "RcppCCTZ" &&
-             !requireNamespace("RcppCCTZ", quietly = TRUE)) {
-    stop(
-      'Package "RcppCCTZ" must be installed for this approach.',
-      call. = FALSE
-    )
+               !requireNamespace("RcppCCTZ", quietly = TRUE)) {
+    stop('Package "RcppCCTZ" must be installed for this approach.')
   }
 
   invisible(funbyApproach)
 }
 
-assertFasttimeOK <- function(.dateTime, .helpers) {
-  if (year(.dateTime[1L]) < 1970L || year(last(.dateTime)) > 2199L) {
-    stop(
-      "Timestamps must be between the years 1970 and 2199 for this approach.",
-      call. = FALSE
-    )
-  }
-  if (!grepl(
-    "^(Etc/)?(UCT|UTC)$|^(Etc/)?GMT(\\+|-)?0?$",
-    .helpers[["timezone"]],
-    ignore.case = TRUE
-  )) {
-    stop(
-      'Time zone must be "UTC" or equivalent for this approach.',
-      call. = FALSE
-    )
-  }
-
-  invisible(TRUE)
-}
-
 assertFilter <- function(x, limit) {
   if (!testMultiClass(x, c("integer", "numeric")) && !is.expression(x)) {
-    stop('"i" must be a numeric vector or an expression.', call. = FALSE)
+    stop('"i" must be a numeric vector or an expression.')
   } else if (testMultiClass(x, c("integer", "numeric"))) {
     assertIntegerish(
       x,
@@ -70,9 +59,9 @@ assertNAstatusPeriodicityOK <- function(
   )
   if (na.status != "explicit" || periodicity == "unrecognised") {
     if (level == "error") {
-      stop(msg, call. = FALSE)
+      stop(msg)
     } else {
-      warning(msg, call. = FALSE)
+      warning(msg)
     }
   }
 
@@ -81,10 +70,7 @@ assertNAstatusPeriodicityOK <- function(
 
 assertNoStartingDot <- function(x) {
   if (any(startsWith(x, "."))) {
-    stop(
-      sprintf('"%s" must not start with a ".".', deparse(substitute(x))),
-      call. = FALSE
-    )
+    stop(sprintf('"%s" must not start with a ".".', deparse(substitute(x))))
   }
 
   invisible(x)
